Please see [https://docs.mlcommons.org/cm4mlops/scripts/TinyML-automation/create-fpgaconvnet-app-tinyml](https://docs.mlcommons.org/cm4mlops/scripts/TinyML-automation/create-fpgaconvnet-app-tinyml) for the documentation of this CM script.
